import { LitElement } from 'lit';
export declare type InputType = 'text' | 'tel' | 'url' | 'email' | 'password' | 'date' | 'month' | 'week' | 'time' | 'datetime-local' | 'number' | 'color';
declare const UUIInputElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 * Custom element wrapping the native input element.This is a formAssociated element, meaning it can participate in a native HTMLForm. A name:value pair will be submitted.
 * @element uui-input
 * @extends LabelMixin(LitElement)
 * @slot input label - for the input label text.
 * @fires UUIInputEvent#change on change
 * @fires InputEvent#input on input
 * @fires KeyboardEvent#keyup on keyup
 */
export declare class UUIInputElement extends UUIInputElement_base {
    static styles: import("lit").CSSResult[];
    static readonly formAssociated = true;
    private _internals;
    constructor();
    /**
     * Defines the input placeholder.
     * @type {string}
     * @attr
     * @default ''
     */
    placeholder: string;
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Set to true to hide the labeling provided by the component.
     * @type {boolean}
     * @attr hide-label
     * @default false
     */
    hideLabel: boolean;
    private _value;
    /**
     * This is a value property of the uui-input.
     * @type {string}
     * @attr
     * @default ''
     */
    get value(): string;
    set value(newValue: string);
    /**
     * This is a name property of the uui-input component. It reflects the behaviour of the native <input> element and its name attribute.
     * @type {string}
     * @attr
     * @default ''
     */
    name: string;
    /**
     * Set to true if the component should have an error state.Property is reflected to the corresponding attribute.
     * @type {boolean}
     * @attr
     * @default false
     */
    error: boolean;
    /**
     * This property specifies the type of input that will be rendered.
     * @type {'text' | 'tel'| 'url'| 'email'| 'password'| 'date'| 'month'| 'week'| 'time'| 'datetime-local'| 'number'| 'color'}
     * @attr
     * @default text
     */
    type: InputType;
    private onInput;
    private onChange;
    render(): import("lit-html").TemplateResult<1>;
}
export {};
